# GAPlanetS

[![Powered by pyKLIP](https://img.shields.io/badge/powered_by-pyKLIP-EB5368.svg?style=flat)](https://bitbucket.org/pyKLIP/pyklip/src/master/)

The GAPLanets package contains all the data reduction tools used in the processing of the Giant Accreting Protoplanet Survey.

## Installation

The modules in this package require Python version 3.8.5 or above.

To install the relevant packages and ensure your dependencies are met, you can reference our requirements.txt

```bash
pip install -r requirements.txt
```

Now, all the necessary packages should be installed!
